@@ -4,7 +4,7 @@
 const assert = require('assert');
 const asn1 = require('..');
 
-const Buffer = require('buffer').Buffer;
+const Buffer = require('safer-buffer').Buffer;
 
 describe('asn1.js DER decoder', function() {
   it('should propagate implicit tag', function() {
@@ -20,7 +20,7 @@ describe('asn1.js DER decoder', function() {
       );
     });
 
-    const out = A.decode(new Buffer('300720050403313233', 'hex'), 'der');
+    const out = A.decode(Buffer.from('300720050403313233', 'hex'), 'der');
     assert.equal(out.a.b.toString(), '123');
   });
 
@@ -31,7 +31,7 @@ describe('asn1.js DER decoder', function() {
         this.optional().key('opt').bool()
       );
     });
-    const out = A.decode(new Buffer('30030101ff', 'hex'), 'der');
+    const out = A.decode(Buffer.from('30030101ff', 'hex'), 'der');
     assert.deepEqual(out, { 'key': true });
   });
 
@@ -42,14 +42,14 @@ describe('asn1.js DER decoder', function() {
         this.optional().key('opt').octstr().def('default')
       );
     });
-    const out = A.decode(new Buffer('30030101ff', 'hex'), 'der');
+    const out = A.decode(Buffer.from('30030101ff', 'hex'), 'der');
     assert.deepEqual(out, { 'key': true, 'opt': 'default' });
   });
 
   function test(name, model, inputHex, expected) {
     it(name, function() {
       const M = asn1.define('Model', model);
-      const decoded = M.decode(new Buffer(inputHex,'hex'), 'der');
+      const decoded = M.decode(Buffer.from(inputHex,'hex'), 'der');
       assert.deepEqual(decoded, expected);
     });
   }
@@ -69,7 +69,7 @@ describe('asn1.js DER decoder', function() {
       this.optional().use(B);
     });
 
-    const out = A.decode(new Buffer('020101', 'hex'), 'der');
+    const out = A.decode(Buffer.from('020101', 'hex'), 'der');
     assert.equal(out.toString(10), '1');
   });
 
@@ -81,7 +81,7 @@ describe('asn1.js DER decoder', function() {
 
   test('should decode objDesc', function() {
     this.objDesc();
-  }, '0703323830', new Buffer('280'));
+  }, '0703323830', Buffer.from('280'));
 
   test('should decode bmpstr', function() {
     this.bmpstr();
@@ -108,7 +108,7 @@ describe('asn1.js DER decoder', function() {
       this.octstr().contains(B);
     });
 
-    const out = A.decode(new Buffer('04053003020105', 'hex'), 'der');
+    const out = A.decode(Buffer.from('04053003020105', 'hex'), 'der');
     assert.equal(out.nested.toString(10), '5');
   });
 
@@ -141,14 +141,14 @@ describe('asn1.js DER decoder', function() {
       );
     });
 
-    let out = A.decode(new Buffer(
+    let out = A.decode(Buffer.from(
       '3018300A30030201013003020102300A30030201033003020104', 'hex'), 'der');
     assert.equal(out.test1[0].num.toString(10), 1);
     assert.equal(out.test1[1].num.toString(10), 2);
     assert.equal(out.test2[0].num.toString(10), 3);
     assert.equal(out.test2[1].num.toString(10), 4);
 
-    out = A.decode(new Buffer('300C300A30030201013003020102', 'hex'), 'der');
+    out = A.decode(Buffer.from('300C300A30030201013003020102', 'hex'), 'der');
     assert.equal(out.test1[0].num.toString(10), 1);
     assert.equal(out.test1[1].num.toString(10), 2);
     assert.equal(out.test2, undefined);
@@ -161,7 +161,7 @@ describe('asn1.js DER decoder', function() {
        });
      });
      // Note no decoder specified, defaults to 'der'
-     const decoded = M.decode(new Buffer('0101ff', 'hex'));
+     const decoded = M.decode(Buffer.from('0101ff', 'hex'));
      assert.deepEqual(decoded, { 'type': 'apple', 'value': true });
   });
 });
